/* ************************************************************************** */
/** Descriptive File Name:   main.c for Lab 1b

  @ Author
    Richard Wall
 
  @ Date
    Created:    May 28, 2016
    Verified:   February 28, 2017

  @Company
    Digilent Inc

  @Development Environment
    MPLAB X IDE x3.61 - http://www.microchip.com/mplab/mplab-x-ide 
	XC32 1.43 - http://www.microchip.com/mplab/compilers
	PLIB 3/7/20162 - http://www.microchip.com/SWLibraryWeb/product.aspx?product=PIC32%20Peripheral%20Library

  @File Name
    main.c

  @Summary
    Seven segment test program.

  @Description
    Verifies the functionality of the four digit 7 segment displays and
    performs the operations of a simple integer calculator.
  @Remarks
    Uses XC32 peripheral library. See 
 http://ww1.microchip.com/downloads/en/DeviceDoc/32bitPeripheralLibraryGuide.pdf
 http://www.microchip.com/SWLibraryWeb/product.aspx?product=PIC32%20Peripheral%20Library
 */
/* ************************************************************************** */

/* ************************************************************************** */
/* ************************************************************************** */
/* Section: Included Files                                                    */
/* ************************************************************************** */
/* ************************************************************************** */

#include "config_bits.h"    // PIC32MX370 bit configuration
#include "hardware.h"       // Defines hardware IO
#include "swDelay.h"        // Software millisecond time delay
#include "led7.h"           // 4 digit - 7 segment display control
#include "calc.h"           // Switch to 4 bit decimal value
#include <plib.h>           // Peripherial library 

/* ************************************************************************** */
/* ************************************************************************** */
/* Section: File Scope or Global Data                                         */
/* ************************************************************************** */
/* ************************************************************************** */

/*  There are no global variables needed for this application  */

/* ************************************************************************** */
/* ************************************************************************** */
// Section: Local Functions                                                   */
/* ************************************************************************** */
/* ************************************************************************** */

/** 
  @Function
    int main( void ); 

  @Summary
    Initializes the hardware platform and performs the calculator operations.

  @Description
    This file contains the main function that executes initialization followed 
    by an infinite loop that executes the calculator operations. Each time the
    the loop is executed, switches SW0 through SW7 are read.  SW0 through SW3 
    are read as value "x" and SW4 through SW7 are read as value "y". When a push
    button is pressed, the value displayed on the four digit seven segment 
    display is changed to reflect the "x" and "y" values and the operation
    commanded by which ever push button was pressed. 
                 Button Operations
    Button  -   Operation           Comment
     BTND   -   Addition x + y      Down button
     BTNC   -   Subtract x - y      Center button
     BTNR   -   Multiply x * y      Right button
     BTNU   -   Multiply x / y      Up button (not functional in DEBUG mode)
     BTNL   -   Clear Result        Left button (not functional in DEBUG mode)

  @Precondition
    None

  @Parameters
    None

  @Returns
 The system has failed if the last statement is executed. 
    EXIT_FAILURE (1)   Indicates an error occurred
    EXIT_SUCCESS (0)   Indicates an error did not occur
  @Remarks
    BNTU and BTNL are not functional with the current release of the Basys MX3
    board while in DEBUG mode.

 */
int main( void )
{

int x,y;                // Input values x and y
int result = 0;         // Operation result
    Hardware_Setup();   // Initialize switches, buttons and LEDs
    TRISBSET =  0b0000111000000000;  // RB9, RB10, RB11 are input   
    ANSELBCLR = 0b0000111000000000;  // ANSB9, ANSB10, ANSB11 = 0
    Set_All_LEDs_On();
    seg7_init();        // Initialize IO pins for 7 segment display
    test_7seg_leds();   // Perform 4 digit - 7 segment display test
    Set_All_LEDs_Off();
    Set_LED8_R(1);
    msDelay(250);
    Set_LED8_G(1);
    msDelay(250);
    Set_LED8_B(1);
    msDelay(250);
    Set_LED8_RGB(0);
    msDelay(500);
    
    while(1)
    {
        get_xy(&x, &y);  // Input x and y values
        
        if(BNTC())       // Subtract
        {
            Set_All_LEDs_Off();
            setLED0(1);
            result = x - y;
        }
        if(BNTD())       // Add
        {
            Set_All_LEDs_Off();
            setLED1(1);
            result = x + y;
       }
        if(BNTR())       // Multiply
        {
            Set_All_LEDs_Off();
            setLED2(1);
            result = x * y;
        }
#ifndef DEBUG_MODE
        if(BNTU())     // divide  - Button not functional in DEBUG mode
        {
            Set_All_LEDs_Off();
            setLED3(1);
            if(y != 0 )
                result = x / y;
            else
                result = 9999;
        }
        if(BNTL())     // Clear display   - Button not functional in DEBUG mode
        {
            Set_All_LEDs_Off();
            setLED4(1);
            result = 0x00;
        } 
#endif
        led_number(result); // Display result on LED

    } /* End while(1) loop */
    return (EXIT_FAILURE);      // Should never reach this statement
}

/* *****************************************************************************
 End of File main.c
 */
