/* ************************************************************************** */
/** Descriptive File Name: Lab5.c is the main entry point for Unit 5 project 
    code that reads the codes from an NEC IrDA remote control device. 

  @Company
    Digilent

  @ Author
    Richard Wall
 
  @Date
    Created:    August 2, 2016
    Verified:   May 20, 2017
  
  @File Name
    lab5.c

  @Summary
    IrDA test program.

  @Description
        A flag indicates when a new new has been pressed and the decode bit
    stream. This program reports the decoded IrDA keys.

    Variable - "new_key" indicates new data is ready for display
    Variable - "key" is the four byte key value comprising of an address code
               and a value code
    <p>
        A common INT1 ISR is used for the selected IrDA protocol. 
    
    <p>
        The processes initializes the the hardware resources including the 
    motor driver output pins that are used for instrumentation since these pins
    are routed to the Analog Discovery connector. 
  @Remarks
    Only two of many possible IrDa codes are decoded: NEC and Pulse Length.
    SW7 = 0 selects the Rx mode.  This program is written to decode the SONY
    Model RM-VL-Z620 Remote Commander.
 
 ****   This application uses a peripheral bus clock set to 10MHz.  ****
 
 * ************************************************************************** */

/* ************************************************************************** */
/* ************************************************************************** */
/* Section: Included Files                                                    */
/* ************************************************************************** */
/* ************************************************************************** */

// System included files
#include "config_bits.h"
#include "hardware.h"
#include <plib.h>
#include <stdio.h>

// Included files for platform
#include "swDelay.h"
#include "LCDlib.h"
#include "comm_lib.h"

// Included files for application
// #include "Lab5.h"
#include "IRDA.h"

// Global data to interface with ISR
extern unsigned int new_key;
extern unsigned int key;

int main(void)
{
char codeStr[33];           // Output text string
int a,b,c,d;                // Decoded bytes
int led1 = 0;               // Received new key code flag
int led2 = 0;               // Send new key code flag

    Hardware_Setup();       // COnfigure Basys MX3 platform IO

// ========================  Test outputs ===============================
//    PORTSetPinsDigitalOut(IOPORT_B, AIN1bit); // AIN1 for output - Pulse pd.
//    PORTSetPinsDigitalOut(IOPORT_E, AIN2bit); // AIN2 for output - not used

//    PORTSetPinsDigitalOut(IOPORT_B, BIN2bit); // BIN2 for output - decoded
//    PORTSetPinsDigitalOut(IOPORT_E, BIN1bit); // BIN1 for output - sync

//    PORTClearBits(IOPORT_E, BIN1bit); // Reset BIN1 for output
//    PORTClearBits(IOPORT_B, BIN2bit); // Reset BIN2 output
// ====================================================================== 
    
    initLCD();
    putsLCD("IrDA Tester");
    uart4_init(57600, NO_PARITY);
    irda_init();
    while(1)
    {
        if(SW7() == 1)
        {
            SetDCOC5PWM(IRDA_38K_ON);   // Generates 38KHz output
        }
        else
        {
            SetDCOC5PWM(IRDA_38K_IDLE); // Rx mode
        }
    
        if(BNTD() == 1)
        {
            idra_nec_send_code(NEC_UP);
            led2 ^= 1;
            setLED2(led2);
            msDelay(1000);
        }
        
        if(new_key)                 // Check for new decoded IrDA message
        {
            led1 ^= 1;              // Toggle LED1 to signal new key
            setLED1(led1);
            BIN1(0);                // Reset BIN1 output - Serial Data
            BIN2(0);                // Reset BIN2 output - Start trig
            a = (key >> 24) & 0xff; // key is a 32 bit variable
            b = (key >> 16) & 0xff;
            c = (key >> 8) & 0xff;
            d = (key >> 0)  & 0xff;
            sprintf(codeStr,"%2X %2X %2X %2X", d,c,b,a);
            clrLCD();
            putsLCD(codeStr);                       // Display to 4 bytes
            printf("%d [ %s ]\n\r", led1, codeStr);
            new_key = 0;                            // Ready for new key press
        }
    }
}
// End of Lab5.c
