/* ************************************************************************** */
/** Descriptive File Name: RC.c - Remote servo controller demonstration program

  @ Author  
     Richard Wall
  
  @ Date: 
     Created:    March 3, 2017
     Verified:	 May 21, 2017
	 
  @Company
    Digilent Inc

  @File Name
    RC.h

  @Development Environment
    MPLAB X IDE x3.61 - http://www.microchip.com/mplab/mplab-x-ide 
	XC32 1.43 - http://www.microchip.com/mplab/compilers
	PLIB 3/7/20162 - http://www.microchip.com/SWLibraryWeb/product.aspx?product=PIC32%20Peripheral%20Library

  @Summary
    Test program for the 2 channel Servo Motor using the Basys MX3.

  @Description
    See RC.txt under the Reference folder

**************************************************************************** */
 

#ifndef __RC__
	#define __RC__

    #define cfgRC2()    do{PORTSetPinsDigitalOut(IOPORT_B, BIT_8); RPB8R = 0x0B;}while(0)  // BTNR - OC5
    #define cfgRC1()    do{PORTSetPinsDigitalOut(IOPORT_A, BIT_15); RPA15R = 0x0B;}while(0) // BTND - OC4
// RC Channel pin assignment macros
	#define RC_1(a)     SetDCOC4PWM(a); //LATBbits.LATB8 = a
	#define RC_2(a) 	SetDCOC5PWM(a); //LATAbits.LATA15 = a


	#define NRC		2	// Number of RC channels

// RC Setting range
    #define PWM_RATE    50
    #define PWM_PD      GetPeripheralClock()/4/PWM_RATE // TIMER Prescale = 4 
	#define RC_MIN		(PWM_PD / 20)
	#define	RC_MAX		(PWM_PD / 10 )
	#define RC_SPAN		(RC_MAX-RC_MIN)
	#define RC_CENTER   (RC_MIN + (RC_SPAN / 2))
#endif

/* Public Functions */
void initRC(void);
void set_RC(int ch, int ctrl);
void check_switches(void);

/* End of RC.h */
